from fastapi import FastAPI
from fastapi.middleware.cors import CORSMiddleware
from app.api.todos import router as todos_router
from app.db.base import Base
from app.db.session import engine

# Create database tables
Base.metadata.create_all(bind=engine)

app = FastAPI(
    title="Todo API",
    description="A simple Todo API built with FastAPI",
    version="1.0.0",
    openapi_url="/openapi.json"
)

# Add CORS middleware
app.add_middleware(
    CORSMiddleware,
    allow_origins=["*"],
    allow_credentials=True,
    allow_methods=["*"],
    allow_headers=["*"],
)

# Include routers
app.include_router(todos_router, prefix="/api/v1")


@app.get("/")
def root():
    """
    Root endpoint that returns basic information about the API.
    """
    return {
        "title": "Todo API",
        "description": "A simple Todo API built with FastAPI",
        "version": "1.0.0",
        "documentation": "/docs",
        "health_check": "/health"
    }


@app.get("/health")
def health_check():
    """
    Health check endpoint to verify the application is running.
    """
    return {
        "status": "healthy",
        "message": "Todo API is running successfully"
    }